# GenomicRanges

Python equivalent to Bioconductor's [GenomicRanges](https://bioconductor.org/packages/release/bioc/html/GenomicRanges.html) to represent genomic locations and support genomic analysis. It uses efficient structures already available in the Python/Pandas/numpy eco-system adds an familiar interfaces.


## Install

Package is deployed to [PyPI](https://pypi.org/project/genomicranges/)

```shell
pip install genomicranges
```

## Contents

* [Overview](readme)
* [Tutorial](tutorial)
* [License](license)
* [Authors](authors)
* [Changelog](changelog)
* [Module Reference](api/modules)


## Indices and tables

```eval_rst
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
```

[Sphinx]: http://www.sphinx-doc.org/
[Markdown]: https://daringfireball.net/projects/markdown/
[reStructuredText]: http://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
[recommonmark]: https://recommonmark.readthedocs.io/en/latest
[autostructify]: https://recommonmark.readthedocs.io/en/latest/auto_structify.html
